Package: llm.api
Title: Minimal LLM Chat Interface
Version: 0.1.4
Date: 2026-05-24
Authors@R: c(
    person("Troy", "Hernandez", role = c("aut", "cre"),
           email = "troy@cornball.ai",
           comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"),
    person("ellmer team", role = "cph",
           comment = "API design derived from ellmer"))
Description: A minimal-dependency client for Large Language Model chat APIs.
    Supports 'OpenAI' <https://openai.com/>, 'Anthropic' 'Claude'
    <https://claude.com/>, 'Moonshot' 'Kimi' <https://www.moonshot.ai/>,
    'Ollama' <https://ollama.com/>, and other 'OpenAI'-compatible
    endpoints. Includes an agent loop with tool use and a 'Model Context
    Protocol' client <https://modelcontextprotocol.io/>. API design is
    derived from the 'ellmer' package, reimplemented with only base R,
    'curl', and 'jsonlite'.
License: MIT + file LICENSE
URL: https://github.com/cornball-ai/llm.api
BugReports: https://github.com/cornball-ai/llm.api/issues
Encoding: UTF-8
Imports: curl, jsonlite
Suggests: tinytest
NeedsCompilation: no
Packaged: 2026-05-24 22:53:00 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph],
  ellmer team [cph] (API design derived from ellmer)
Maintainer: Troy Hernandez <troy@cornball.ai>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-05-25 15:50:14 UTC
Built: R 4.6.0; ; 2026-05-25 18:13:30 UTC; unix
