Package: llm.api
Title: Minimal LLM Chat Interface
Version: 0.1.9
Date: 2026-08-04
Authors@R: c(
    person("Troy", "Hernandez", role = c("aut", "cre"),
           email = "troy@cornball.ai",
           comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"),
    person("ellmer team", role = "cph",
           comment = "API design derived from ellmer"))
Description: A minimal-dependency client for Large Language Model chat APIs.
    Supports 'OpenAI' <https://openai.com/>, 'Anthropic' 'Claude'
    <https://claude.com/>, 'Moonshot' 'Kimi' <https://www.moonshot.ai/>,
    'OpenAI' 'Codex' subscription endpoints, 'Ollama'
    <https://ollama.com/>, and other 'OpenAI'-compatible endpoints.
    Includes an agent loop with tool use and a 'Model Context
    Protocol' client <https://modelcontextprotocol.io/>. API design is
    derived from the 'ellmer' package, reimplemented with only base R,
    'curl', 'jsonlite', and 'tinyoauth'.
License: MIT + file LICENSE
URL: https://github.com/cornball-ai/llm.api
BugReports: https://github.com/cornball-ai/llm.api/issues
Encoding: UTF-8
Imports: curl, jsonlite, tinyoauth (>= 0.1.1)
Suggests: tinytest
NeedsCompilation: no
Packaged: 2026-08-04 19:41:14 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph],
  ellmer team [cph] (API design derived from ellmer)
Maintainer: Troy Hernandez <troy@cornball.ai>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-08-04 21:50:02 UTC
Built: R 4.6.0; ; 2026-08-04 23:03:43 UTC; unix
