% tinyrox says don't edit this manually, but it can't stop you!
\name{list_ollama_models}
\alias{list_ollama_models}
\title{List Ollama models}
\usage{
list_ollama_models(base_url = "http://localhost:11434")
}
\arguments{
\item{base_url}{Character. Ollama server URL (default: http://localhost:11434).}
}
\value{
A data frame with model information (name, size, modified).
}
\description{
List all models downloaded in Ollama.
}
\examples{
\dontrun{
list_ollama_models()
}
}
