% tinyrox says don't edit this manually, but it can't stop you!
\name{chat_session_anthropic}
\alias{chat_session_anthropic}
\title{Create Anthropic chat session}
\usage{
chat_session_anthropic(model = "claude-sonnet-4-6", system_prompt = NULL, ...)
}
\arguments{
\item{model}{Character. Model name (default: "claude-sonnet-4-6").}

\item{system_prompt}{Character or NULL. System prompt.}

\item{...}{Additional parameters passed to chat_session().}
}
\value{
A chat session list.
}
\description{
Convenience wrapper for chat_session with Anthropic provider.
}
\examples{
# Construct a session (no network call yet)
session <- chat_session_anthropic(system_prompt = "You are helpful.")
\dontrun{
session$chat("Hello")
}
}
